function W = WIR(Enl2, l2, Enl1, l1, F21, B, DELTA, LAMBDA, delta)
% Interface Roughness Scattering rate between levels (n2, l2) and (n1, l1)
    
    global NDLcut e hbar Angstrom NIRcut NIRstep
    
    global INTir
    
    if (abs(Enl2 - Enl1) > NDLcut * delta)
        W = 0;
    else
        beta = sqrt(e * B / hbar) * Angstrom; % 1 / Angstrom

        alphal1 = sqrt(beta / 2 ^ l1 / factorial(l1) / sqrt(pi)); % 1 / sqrt(Angstrom)
        alphal2 = sqrt(beta / 2 ^ l2 / factorial(l2) / sqrt(pi)); % 1 / sqrt(Angstrom)
        
        if (INTir(l2 + 1, l1 + 1) > 0)
            G = INTir(l2 + 1, l1 + 1);
        else 
            % Relative boundaries for kx12, t and s
            NIRcutl2l1 = NIRcut * (1 + (l2 + l1) / 150);
            
            % Relative boundary and time step size for kx12 = kx1 - kx2
            kx12cut = NIRcutl2l1 / sqrt(LAMBDA ^ 2 / 4 + 1 / 2 / beta ^ 2); % 1 / Angstrom
            dkx12 = 2 * kx12cut / NIRstep; % 1 / Angstrom
            kx12 = -kx12cut : dkx12 : kx12cut;

            % Relative boundary and time step size for t
            tcut = NIRcutl2l1 / beta; % A
            dt = 2 * tcut / NIRstep; % A
            t = -tcut : dt : tcut;
            
            % Relative boundary and time step size for s
            scut = NIRcutl2l1 / beta; % A
            ds = 2 * scut / NIRstep; % A
            s = -scut : ds : scut;
                        
            % Simpson numerical integration for kx12
            % -------------------------------------------------------------
            % simpson1D -> odd number
            if (rem(length(kx12), 2) == 0)
                kx12 = kx12(1 : end - 1);
                % new time step size for kx12
                dkx12 = (kx12(end) - kx12(1)) / (length(kx12) -  1);
            end
            % simpson 1D
            sim1d = ones(1, length(kx12));
            sim1d = 4 * (rem(find(sim1d), 2) == 0) + 2 * (rem(find(sim1d), 2) == 1);
            sim1d(1) = 1;
            sim1d(end) = 1;
            % -------------------------------------------------------------
            
            % Simpson numerical integration for t and s
            % -------------------------------------------------------------
            % simpson1D -> odd number
            if (rem(length(t), 2) == 0)
                t = t(1 : end - 1);
                % new time step size for t
                dt = (t(end) - t(1)) / (length(t) -  1);
            end
            % simpson 1D
            sim1d1 = ones(1, length(t));
            sim1d1 = 4 * (rem(find(sim1d1), 2) == 0) + 2 * (rem(find(sim1d1), 2) == 1);
            sim1d1(1) = 1;
            sim1d1(end) = 1;
            % simpson1D -> odd number
            if (rem(length(s), 2) == 0)
                s = s(1 : end - 1);
                % new time step size for s
                ds = (s(end) - s(1)) / (length(s) -  1);
            end
            % simpson 1D
            sim1d2 = ones(1, length(s));
            sim1d2 = 4 * (rem(find(sim1d2), 2) == 0) + 2 * (rem(find(sim1d2), 2) == 1);
            sim1d2(1) = 1;
            sim1d2(end) = 1;
            % simpson 2D
            [sim2d1, sim2d2] = meshgrid(sim1d1, sim1d2);
            sim2d = sim2d1 .* sim2d2;
            % -------------------------------------------------------------

            % 2D meshgrid
            [t, s] = meshgrid(t, s);

            G = 0;
            for i = 1 : length(kx12)
                G = G + sim1d(i) * sum(sum(sim2d .* exp(- (LAMBDA ^ 2 / 4 + 1 / beta ^ 2 / 2) * kx12(i) ^ 2) .* exp(- s .^ 2 / LAMBDA ^ 2) .* ...
                        (exp(- beta ^ 2 * t .^ 2) .* (alphal1 * mH(l1, beta * t - kx12(i) / beta / 2)) .* ...
                                                     (alphal2 * mH(l2, beta * t + kx12(i) / beta / 2))) .* ...
                        (exp(- beta ^ 2 * (t - s) .^ 2) .* (alphal1 * mH(l1, beta * (t - s) - kx12(i) / beta / 2)) .* ...
                                                           (alphal2 * mH(l2, beta * (t - s) + kx12(i) / beta / 2)))));            
            end

            G = G * dkx12 * dt * ds / 27;
            
            INTir(l2 + 1, l1 + 1) = G;
            INTir(l1 + 1, l2 + 1) = G;
        end

        S = sum(abs(F21) .^ 2) * DELTA ^ 2 * LAMBDA * G / sqrt(pi);

        W = 2 * pi / hbar * JIR(Enl2, Enl1, delta) * S;

        W = W * e; % 1 / s
    end

end
