% Callback function for "plot all"

% Fig1. The subband positions at zero magnetic fields, together with the
% coresponding wave functions squared
% ------------------------------------------------------------------------- 
z = dlmread('z.txt',',');
U = dlmread('U.txt',',');
fid = fopen('enrgwave.txt','r');
Nn = fscanf(fid, '%d', 1);
Nz = fscanf(fid, '%d', 1);

En = zeros(1, Nn);
for i = 1 : Nn
    En(i) = fscanf(fid, '%f', 1);
end
eta = zeros(Nn, Nz);
for j = 1 : Nz
    for i = 1 : Nn
        eta(i, j) = fscanf(fid, '%f', 1);
    end
end
fclose(fid);
hold off
subplot(2,2,1, 'Parent', panelFigure)
plot(z, U,'linewidth',font_scale*4)
xlabel(['z [',197,']'],'FontSize',font_scale*20)
ylabel('U [eV]','FontSize',font_scale*20)
title('Conduction band diagram. Wave functions','FontWeight','bold','FontSize',font_scale*15)
hold on
for i = 1 : 3
    plot( z(1 : floor(end / 100) : end), En(i), 'b--','linewidth',font_scale*4)
    text(z(1), En(i), ['\color{blue}', '{\itE}_{', int2str(i), '}'], 'HorizontalAlignment','right','FontSize',font_scale*20)
    plot(z, En(i) + eta(i, :) .* eta(i, :), 'r','linewidth',font_scale*4)
end
set(gca,'FontSize',font_scale*20)

% load results from file 'res.txt'
% -------------------------------------------------------------------------
fid = fopen('res.txt','r');
NB = fscanf(fid, '%d', 1);
Bmin = fscanf(fid, '%f', 1);
dB = fscanf(fid, '%f', 1);
Bmax = fscanf(fid, '%f', 1);
TEMP = fscanf(fid, '%f', 1);
B = zeros(1, NB);
W30lo = zeros(1, NB);
W30ir = zeros(1, NB);
W30loir = zeros(1, NB);
N20lo = zeros(1, NB);
N30lo = zeros(1, NB);
N20loir = zeros(1, NB);
N30loir = zeros(1, NB);
g32lo = zeros(1, NB);
g32loir = zeros(1, NB);
for i = 1 : NB
    B(i) = fscanf(fid, '%f ', 1);
    W30lo(i) = fscanf(fid, '%f', 1);
    W30ir(i) = fscanf(fid, '%f', 1);
    W30loir(i) = fscanf(fid, '%f', 1);
    N20lo(i) = fscanf(fid, '%f', 1);
    N30lo(i) = fscanf(fid, '%f', 1);
    N20loir(i) = fscanf(fid, '%f', 1);
    N30loir(i) = fscanf(fid, '%f', 1);
    g32lo(i) = fscanf(fid, '%f', 1);
    g32loir(i) = fscanf(fid, '%f', 1);
end
fclose(fid);
% -------------------------------------------------------------------------


% Fig2. The total electron relaxation rate for transitions from (3, 0) subband 
% into the (2, l) and (1, l) subbands
% -------------------------------------------------------------------------
subplot(2,2,2), 
plot(B, W30lo, '--', B, W30ir, '-.', B, W30loir,'linewidth',font_scale*4)
xlabel('B [T]','FontSize',font_scale*15)
ylabel('1 / \tau_{3,0} [1/ps]','FontSize',font_scale*15)
title('Relaxation rate','FontWeight','bold','FontSize',font_scale*15)
h = legend('1/\tau_{\rm LO}', '1/\tau_{\rm IR}', '1/\tau_{\rm LO} + 1/\tau_{\rm IR}', 'Location', 'Best');
set(h, 'Box', 'off','FontSize',font_scale*15)
set(gca,'FontSize',font_scale*20)

% Fig3. The ratio of the total electron areal densities in the ground laser
% levels of the third and the second subband
% -------------------------------------------------------------------------
subplot(2,2,3), 
plot(B, N30lo ./ N20lo, 'b--', B, N30loir ./ N20loir, 'r','linewidth',font_scale*4)
title('Population inversion','FontWeight','bold','FontSize',font_scale*15)
xlabel('B [T]','FontSize',font_scale*15)
ylabel('N_{3,0} / N_{2,0}','FontSize',font_scale*15)
h = legend('1/\tau_{\rm LO}', '1/\tau_{\rm LO} + 1/\tau_{\rm IR}', 'Location', 'Best');
set(h, 'Box', 'off','FontSize',font_scale*15)
set(gca,'FontSize',font_scale*20)

% Fig4. QCL gain
% -------------------------------------------------------------------------
subplot(2,2,4), 
plot(B, g32lo, 'b--', B, g32loir, 'r','linewidth',font_scale*4)
title('The optical gain','FontWeight','bold','FontSize',font_scale*15)
xlabel('B [T]','FontSize',font_scale*15)
ylabel('g [{cm}^2 / {kA}]','FontSize',font_scale*15)
h = legend('1/\tau_{\rm LO}', '1/\tau_{\rm LO} + 1/\tau_{\rm IR}', 'Location', 'Best');
set(h, 'Box', 'off','FontSize',font_scale*15)
set(gca,'FontSize',font_scale*20)