function save_figU
% Save graphic of the active region of QCL 

% The subband positions at zero magnetic fields, together with the
% coresponding wave functions squared
% ------------------------------------------------------------------------- 
z = dlmread('z.txt',',');
U = dlmread('U.txt',',');
fid = fopen('enrgwave.txt','r');
Nn = fscanf(fid, '%d', 1);
Nz = fscanf(fid, '%d', 1);
En = zeros(1, Nn);

for i = 1 : Nn
    En(i) = fscanf(fid, '%f', 1);
end
eta = zeros(Nn, Nz);
for j = 1 : Nz
    for i = 1 : Nn
        eta(i, j) = fscanf(fid, '%f', 1);
    end
end
fclose(fid);

hold off
hF1 = figure(2);
set(hF1,'Visible','off')
plot(z, U,'linewidth',2)
xlabel(['z [',197,']'])
ylabel('U [eV]')
title('Conduction band diagram. Wave functions','FontWeight','bold')
hold on

for i = 1 : 3
    plot( z(1 : floor(end / 100) : end), En(i), 'b--','linewidth',2)
    text(z(1), En(i), ['\color{blue}', '{\itE}_{', int2str(i), '}'], 'HorizontalAlignment','right')
    plot(z, En(i) + eta(i, :) .* eta(i, :), 'r','linewidth',2)
end

[fname,pname] = uiputfile('*.tif','Save figure');
if(fname~=0)
    fname = fname(1:end-4);
    fpname1 = strcat(pname,fname,'_WaveFunc.tif');
    if exist(fpname1,'file')
        delete(fpname1);
    end     
    set(hF1,'PaperPositionMode','auto','InvertHardcopy','off')
    print(hF1,'-dtiff','-r300',fpname1);
end

close(2)

end